==> suricata_8.0.0.orig.tar.gz: suricata-8.0.0/src/build-info.h <==
printf(
"Suricata Configuration:\n"
"  AF_PACKET support:                       yes\n"
"  AF_XDP support:                          no\n"
"  DPDK support:                            no\n"
"  eBPF support:                            no\n"
"  XDP support:                             no\n"
"  PF_RING support:                         no\n"
"  NFQueue support:                         no\n"
"  NFLOG support:                           no\n"
"  IPFW support:                            no\n"
"  Netmap support:                          no \n"
"  DAG enabled:                             no\n"
"  Napatech enabled:                        no\n"
"  WinDivert enabled:                       no\n"
"  Npcap support:                           \n"
"\n"
"  Unix socket enabled:                     yes\n"
"  Detection enabled:                       yes\n"
"\n"
"  Libmagic support:                        yes\n"
"  libjansson support:                      yes\n"
"  hiredis support:                         no\n"
"  hiredis async with libevent:             no\n"
"  PCRE jit:                                yes\n"
"  GeoIP2 support:                          no\n"
"  JA3 support:                             yes\n"
"  JA4 support:                             yes\n"
"  Hyperscan support:                       no\n"
"  Hwloc support:                           no\n"
"  Libnet support:                          yes\n"
"  liblz4 support:                          yes\n"
"  Landlock support:                        yes\n"
"  Systemd support:                         yes\n"
"\n"
"  Rust strict mode:                        no\n"
"  Rust compiler path:                      /root/.cargo/bin/rustc\n"
"  Rust compiler version:                   rustc 1.75.0 (82e1608df 2023-12-21)\n"
"  Cargo path:                              /root/.cargo/bin/cargo\n"
"  Cargo version:                           cargo 1.75.0 (1d8b05cdd 2023-11-20)\n"
"\n"
"  Python support:                          yes\n"
"  Python path:                             /usr/bin/python3\n"
"  Install suricatactl:                     yes\n"
"  Install suricatasc:                      yes\n"
"  Install suricata-update:                 yes\n"
"\n"
"  Profiling enabled:                       no\n"
"  Profiling locks enabled:                 no\n"
"  Profiling rules enabled:                 no\n"
"\n"
"  Plugin support (experimental):           yes\n"
"  DPDK Bond PMD:                           no\n"
"\n"
"Plugins:\n"
"  nDPI:                                    no\n"
"\n"
"Development settings:\n"
"  Coccinelle / spatch:                     no\n"
"  Unit tests enabled:                      no\n"
"  Debug output enabled:                    no\n"
"  Debug validation enabled:                no\n"
"  Fuzz targets enabled:                    no\n"
"\n"
"Generic build parameters:\n"
"  Installation prefix:                     /usr/local\n"
"  Configuration directory:                 /usr/local/etc/suricata/\n"
"  Log directory:                           /usr/local/var/log/suricata/\n"
"\n"
"  --prefix                                 /usr/local\n"
"  --sysconfdir                             /usr/local/etc\n"
"  --localstatedir                          /usr/local/var\n"
"  --datarootdir                            /usr/local/share\n"
"\n"
"  Host:                                    x86_64-pc-linux-gnu\n"
"  Compiler:                                gcc (exec name) / g++ (real)\n"
"  GCC Protect enabled:                     no\n"
"  GCC march native enabled:                yes\n"
"  GCC Profile enabled:                     no\n"
"  Position Independent Executable enabled: no\n"
"  CFLAGS                                   -g -O2 -fPIC -DOS_LINUX -std=c11 -march=native -I${srcdir}/../rust/gen -I${srcdir}/../rust/dist -I../rust/gen\n"
"  PCAP_CFLAGS                              -I/usr/include/dbus-1.0 -I/usr/lib/x86_64-linux-gnu/dbus-1.0/include \n"
"  SECCFLAGS                                \n"
);

==> suricata_8.0.2.orig.tar.gz: suricata-8.0.2/src/build-info.h <==
printf(
"Suricata Configuration:\n"
"  AF_PACKET support:                       yes\n"
"  AF_XDP support:                          no\n"
"  DPDK support:                            no\n"
"  eBPF support:                            no\n"
"  XDP support:                             no\n"
"  PF_RING support:                         no\n"
"  NFQueue support:                         no\n"
"  NFLOG support:                           no\n"
"  IPFW support:                            no\n"
"  Netmap support:                          no \n"
"  DAG enabled:                             no\n"
"  Napatech enabled:                        no\n"
"  WinDivert enabled:                       no\n"
"  Npcap support:                           \n"
"\n"
"  Unix socket enabled:                     yes\n"
"  Detection enabled:                       yes\n"
"\n"
"  Libmagic support:                        yes\n"
"  libjansson support:                      yes\n"
"  hiredis support:                         no\n"
"  hiredis async with libevent:             no\n"
"  PCRE jit:                                yes\n"
"  GeoIP2 support:                          no\n"
"  JA3 support:                             yes\n"
"  JA4 support:                             yes\n"
"  Hyperscan support:                       no\n"
"  Hwloc support:                           no\n"
"  Libnet support:                          yes\n"
"  liblz4 support:                          yes\n"
"  Landlock support:                        yes\n"
"  Systemd support:                         yes\n"
"\n"
"  Rust strict mode:                        no\n"
"  Rust compiler path:                      /root/.cargo/bin/rustc\n"
"  Rust compiler version:                   rustc 1.75.0 (82e1608df 2023-12-21)\n"
"  Cargo path:                              /root/.cargo/bin/cargo\n"
"  Cargo version:                           cargo 1.75.0 (1d8b05cdd 2023-11-20)\n"
"\n"
"  Python support:                          yes\n"
"  Python path:                             /usr/bin/python3\n"
"  Install suricatactl:                     yes\n"
"  Install suricatasc:                      yes\n"
"  Install suricata-update:                 yes\n"
"\n"
"  Profiling enabled:                       no\n"
"  Profiling locks enabled:                 no\n"
"  Profiling rules enabled:                 no\n"
"\n"
"  Plugin support (experimental):           yes\n"
"  DPDK Bond PMD:                           no\n"
"\n"
"Plugins:\n"
"  nDPI:                                    no\n"
"\n"
"Development settings:\n"
"  Coccinelle / spatch:                     no\n"
"  Unit tests enabled:                      no\n"
"  Debug output enabled:                    no\n"
"  Debug validation enabled:                no\n"
"  Fuzz targets enabled:                    no\n"
"\n"
"Generic build parameters:\n"
"  Installation prefix:                     /usr/local\n"
"  Configuration directory:                 /usr/local/etc/suricata/\n"
"  Log directory:                           /usr/local/var/log/suricata/\n"
"\n"
"  --prefix                                 /usr/local\n"
"  --sysconfdir                             /usr/local/etc\n"
"  --localstatedir                          /usr/local/var\n"
"  --datarootdir                            /usr/local/share\n"
"\n"
"  Host:                                    x86_64-pc-linux-gnu\n"
"  Compiler:                                gcc (exec name) / g++ (real)\n"
"  GCC Protect enabled:                     no\n"
"  GCC march native enabled:                yes\n"
"  GCC Profile enabled:                     no\n"
"  Position Independent Executable enabled: no\n"
"  CFLAGS                                   -g -O2 -fPIC -DOS_LINUX -std=c11 -march=native\n"
"  PCAP_CFLAGS                              -I/usr/include/dbus-1.0 -I/usr/lib/x86_64-linux-gnu/dbus-1.0/include \n"
"  SECCFLAGS                                \n"
);
